@@ -90,7 +90,7 @@ class App:
             min_native_zoom=-5,
             max_native_zoom=0,
             tile_size=675,
-            show_loading=False,
+            show_loading=self.map_config.get("show_loading", True),
         )
         self.tiles, self.keybindings = utils.get_tiles(layers)
         for tile in self.tiles:
@@ -315,7 +315,7 @@ class App:
         def _clean_patches(_):
             # Clean buffer if any
             for name, patch in self.patches.items():
-                if "buffer" in patch:
+                if "buffer" in patch and patch["buffer"] is not None:
                     self.m.remove_layer(patch["buffer"])
             self.patches.clear()
             self.draw_control.clear()
@@ -437,23 +437,26 @@ class App:
                     spectra, spec_name_list, lb, ps_dict, cov_dict = method.get("results").values()
                     continue
 
-                patch_dict = utils.build_patch_geometry(patch)
-                spectra, spec_name_list, lb, ps_dict, cov_dict = compute_ps(
-                    patch=patch_dict, maps_info_list=self.maps_info_list, **kwargs
-                )
-                method.update(
-                    dict(
-                        config=kwargs,
-                        results={
-                            "spectra": spectra,
-                            "spec_name_list": spec_name_list,
-                            "lb": lb,
-                            "ps": ps_dict,
-                            "cov": cov_dict,
-                        },
+                try:
+                    patch_dict = utils.build_patch_geometry(patch)
+                    spectra, spec_name_list, lb, ps_dict, cov_dict = compute_ps(
+                        patch=patch_dict, maps_info_list=self.maps_info_list, **kwargs
                     )
-                )
-                patch.update({ps_method: method})
+                    method.update(
+                        dict(
+                            config=kwargs,
+                            results={
+                                "spectra": spectra,
+                                "spec_name_list": spec_name_list,
+                                "lb": lb,
+                                "ps": ps_dict,
+                                "cov": cov_dict,
+                            },
+                        )
+                    )
+                    patch.update({ps_method: method})
+                except Exception as e:
+                    print("An error occured during computation of power spectra : ", str(e))
 
             if spectra is not None:
                 if ps_method == "master":
